#!/usr/bin/perl
use strict;
use XML::RSS;
use HTML::TagFilter;
use LWP::Simple;

my $content;
my $file;
my $tf = HTML::TagFilter->new(deny => {img => {'all'}});


# check for command-line argument
die "Usage: rss2html.pl (<RSS file> | <URL>)\n" unless @ARGV == 1;

# get the command-line argument
my $arg = shift;

# create new instance of XML::RSS
my $rss = new XML::RSS;

# argument is a URL
if ($arg=~ /http:/i) {
    $content = get($arg);
    die "Could not retrieve $arg" unless $content;
    # parse the RSS content
    $rss->parse($content);

# argument is a file
} else {
    $file = $arg;
    die "File \"$file\" does't exist.\n" unless -e $file;
    # parse the RSS file
    $rss->parsefile($file);
}

# print the HTML channel
&print_html($rss);

# SUBROUTINES
sub print_html {
    my $rss = shift;
    print <<HTML;
<html>
<head>
<title>RSS</title>
</head>
<body>

<p><b><a href="$rss->{'channel'}->{'link'}">$rss->{'channel'}->{'title'}</a></B></p>
<br>
HTML

    # One thing I do need to do is remove ALL the images... it is not happy with pictures
    # later on I shall have to get rid of images from channel text too


    	

    # print channel image
    #if ($rss->{'image'}->{'link'}) {
	#print <<HTML;
	#<p><a href="$rss->{'image'}->{'link'}"><img src="$rss->{'image'}->{'url'}" alt="$rss->{'image'}->{'title'}" border="0"
	#HTML
        #print " width=\"$rss->{'image'}->{'width'}\""
	 #   if $rss->{'image'}->{'width'};
	#print " height=\"$rss->{'image'}->{'height'}\""
	#    if $rss->{'image'}->{'height'};
	#print "></a></center><p>\n";
    #}

    # print the channel items
    foreach my $item (@{$rss->{'items'}}) {
	next unless defined($item->{'title'}) && defined($item->{'link'});
	print "<b><a href=\"$item->{'link'}\">$item->{'title'}</a></b><BR>\n";
	print $tf->filter($item->{'description'})."<br>";
    }


    # if there's a textinput element
    if ($rss->{'textinput'}->{'title'}) {
	print <<HTML;
<form method="get" action="$rss->{'textinput'}->{'link'}">
$rss->{'textinput'}->{'description'}<BR> 
<input type="text" name="$rss->{'textinput'}->{'name'}"><BR>
<input type="submit" value="$rss->{'textinput'}->{'title'}">
</form>
HTML
    }

    # if there's a copyright element
    if ($rss->{'channel'}->{'copyright'}) {
	print <<HTML;
<p><sub>$rss->{'channel'}->{'copyright'}</sub></p>

HTML
    }

    print <<HTML;
</body>
</html>
HTML
}
